@@ -95,7 +95,7 @@ volatile int received_signal = rs_NONE;
 bool must_quit = false;
 int open_connections = 0;
 
-char *hs_conlen      = "Content-Length: ";
+char *hs_conlen      = "Content-Length: "; /* 16 */
 char *fb_filesystem  = "access denied via filesystem";
 char *fb_symlink     = "symlink not allowed";
 char *fb_accesslist  = "access denied via accesslist";
@@ -132,18 +132,18 @@ char *version_string = "Hiawatha v"VERSION
 
 /* Create all logfiles with the right ownership and accessrights
  */
-void touch_logfiles(t_config *config, char *dir) {
+void touch_logfiles(t_config *config) {
 	t_host *host;
 
-	touch_logfile(dir, config->system_logfile, LOG_PERM, config->server_uid, config->server_gid);
+	touch_logfile(config->system_logfile, LOG_PERM, config->server_uid, config->server_gid);
 	if (config->garbage_logfile != NULL) {
-		touch_logfile(dir, config->garbage_logfile, LOG_PERM, config->server_uid, config->server_gid);
+		touch_logfile(config->garbage_logfile, LOG_PERM, config->server_uid, config->server_gid);
 	}
 	if (config->exploit_logfile != NULL) {
-		touch_logfile(dir, config->exploit_logfile, LOG_PERM, config->server_uid, config->server_gid);
+		touch_logfile(config->exploit_logfile, LOG_PERM, config->server_uid, config->server_gid);
 	}
 #ifdef DEBUG
-	touch_logfile(dir, LOG_DIR"/debug.log", LOG_PERM, config->server_uid, config->server_gid);
+	touch_logfile(LOG_DIR"/debug.log", LOG_PERM, config->server_uid, config->server_gid);
 #endif
 
 	host = config->first_host;
@@ -151,8 +151,8 @@ void touch_logfiles(t_config *config, char *dir) {
 		if (host->access_fileptr != NULL) {
 			fflush(host->access_fileptr);
 		}
-		touch_logfile(dir, host->access_logfile, LOG_PERM, config->server_uid, config->server_gid);
-		touch_logfile(dir, host->error_logfile, LOG_PERM, config->server_uid, config->server_gid);
+		touch_logfile(host->access_logfile, LOG_PERM, config->server_uid, config->server_gid);
+		touch_logfile(host->error_logfile, LOG_PERM, config->server_uid, config->server_gid);
 		host = host->next;
 	}
 }
@@ -351,7 +351,7 @@ int run_program(t_session *session, char *program, int return_code) {
 int fetch_request(t_session *session) {
 	char *new_reqbuf, *strstart, *strend;
 	long max_request_size, bytes_read, header_length = -1, content_length = -1;
-	int result = 200, write_bytes;
+	int result = 200, write_bytes, select_result;
 	time_t deadline;
 	fd_set read_fds;
 	struct timeval select_timeout;
@@ -463,9 +463,11 @@ int fetch_request(t_session *session) {
 						break;
 					}
 				}
+
 				if (content_length > -1) {
 					if (store_on_disk) {
 						if (session->uploaded_size == content_length) {
+							/* Received a complete PUT request */
 							break;
 						}
 					} else {
@@ -483,7 +485,15 @@ int fetch_request(t_session *session) {
 
 		select_timeout.tv_sec = 1;
 		select_timeout.tv_usec = 0;
-		switch (select(session->client_socket + 1, &read_fds, NULL, NULL, &select_timeout)) {
+
+#ifdef HAVE_SSL
+		select_result = session->binding->use_ssl ? ssl_pending(session->ssl_data) : 0;
+
+		if (select_result == 0)
+#endif
+			select_result = select(session->client_socket + 1, &read_fds, NULL, NULL, &select_timeout);
+
+		switch (select_result) {
 			case -1:
 				if (errno != EINTR) {
 					session->error_cause = ec_SOCKET_READ_ERROR;
@@ -541,7 +551,8 @@ int fetch_request(t_session *session) {
 						break;
 					default:
 						if (store_on_disk) {
-							/* Write to file on disk */
+							/* Write to file on disk
+							 */
 							write_bytes = bytes_read;
 							if (session->uploaded_size + bytes_read > content_length) {
 								write_bytes -= ((session->uploaded_size + bytes_read) - content_length);
@@ -562,7 +573,8 @@ int fetch_request(t_session *session) {
 								keep_reading = false;
 							}
 						} else {
-							/* Read into memory */
+							/* Read into memory
+							 */
 							session->bytes_in_buffer += bytes_read;
 							*(session->request + session->bytes_in_buffer) = '\0';
 
@@ -2029,11 +2041,7 @@ int run_server(t_settings *settings) {
 
 	/* Create logfiles
 	 */
-#ifdef HAVE_CHROOT
-	touch_logfiles(config, config->server_root);
-#else
-	touch_logfiles(config, "");
-#endif
+	touch_logfiles(config);
 
 	/* Change userid
 	 */
