@@ -15,6 +15,9 @@
 #include <string.h>
 #include <sys/socket.h>
 #include <netdb.h>
+#ifdef HAVE_ARPA_INET_H
+#include <arpa/inet.h>
+#endif
 #include "libstr.h"
 #include "libip.h"
 
