@@ -164,7 +164,7 @@ SSL_CTX *ssl_binding(char *keyfile, char *ca_cert, int verify_depth, int port, c
 		return NULL;
 	}
 
-	SSL_CTX_set_options(context, SSL_OP_NO_SSLv2);
+	SSL_CTX_set_options(context, SSL_OP_NO_SSLv2 | SSL_OP_CIPHER_SERVER_PREFERENCE);
 
 	if (SSL_CTX_use_certificate_chain_file(context, keyfile) != 1) {
 		fprintf(stderr, "Error while reading certificate (chain) from %s\n", keyfile);
