@@ -36,7 +36,7 @@ static const struct {
 	const char *text;
 } sqli_detection[] = {
 	{"union\\s*select"},
-	{"[\\s'0-9a-z]\\s*--\\s*.*"},
+	{"[\\s'0-9a-z]\\s*--[ \\t]+.+"},
 	{"'\\s*(and|or|&&|\\|\\|)\\s*('|[0-9]|[a-z.]*\\s*=)"},
 	{NULL}
 };
@@ -594,6 +594,8 @@ int prevent_sqli(t_session *session, char *str, int length) {
 		pattern = pattern->next;
 	}
 
+	free(data);
+
 	return result;
 }
 
