@@ -814,10 +814,8 @@ int execute_cgi(t_session *session) {
 										cache_time = str2int(str_begin);
 										*str_end = '\r';
 
-										if (cache_time != -1) {
-											if (cache_time < MIN_CGI_CACHE_TIMER) {
-												cache_time = MIN_CGI_CACHE_TIMER;
-											} else if (cache_time > MAX_CGI_CACHE_TIMER) {
+										if (cache_time >= MIN_CGI_CACHE_TIMER) {
+											if (cache_time > MAX_CGI_CACHE_TIMER) {
 												cache_time = MAX_CGI_CACHE_TIMER;
 											}
 
