@@ -585,7 +585,7 @@ int show_index(t_session *session) {
 
 	/* Start XML
 	 */
-	if (add_str(&text_xml, &text_max, XML_CHUNK_LEN, &text_size, "<index>") == -1) {
+	if (add_str(&text_xml, &text_max, XML_CHUNK_LEN, &text_size, "<?xml version=\"1.0\" encoding=\"ISO-8859-1\"?>\n<index>") == -1) {
 		free(text_xml);
 		remove_filelist(filelist);
 		return -1;
