@@ -9,6 +9,9 @@
  * GNU General Public License for more details.
  */
 
+#ifndef _XSLT_H
+#define _XSLT_H
+
 #include <stdbool.h>
 #include "session.h"
 
@@ -16,3 +19,5 @@ void init_xslt_module();
 bool can_transform_with_xslt(t_session *session);
 int transform_xml(t_session *session);
 int show_index(t_session *session);
+
+#endif
